==> grpc-1.75.0.gh.tar.gz: grpc-1.75.0/doc/g_stands_for.md <==
'g' stands for something different every gRPC release:

- 1.0 'g' stands for ['gRPC'](https://github.com/grpc/grpc/tree/v1.0.x)
- 1.1 'g' stands for ['good'](https://github.com/grpc/grpc/tree/v1.1.x)
- 1.2 'g' stands for ['green'](https://github.com/grpc/grpc/tree/v1.2.x)
- 1.3 'g' stands for ['gentle'](https://github.com/grpc/grpc/tree/v1.3.x)
- 1.4 'g' stands for ['gregarious'](https://github.com/grpc/grpc/tree/v1.4.x)
- 1.6 'g' stands for ['garcia'](https://github.com/grpc/grpc/tree/v1.6.x)
- 1.7 'g' stands for ['gambit'](https://github.com/grpc/grpc/tree/v1.7.x)
- 1.8 'g' stands for ['generous'](https://github.com/grpc/grpc/tree/v1.8.x)
- 1.9 'g' stands for ['glossy'](https://github.com/grpc/grpc/tree/v1.9.x)
- 1.10 'g' stands for ['glamorous'](https://github.com/grpc/grpc/tree/v1.10.x)
- 1.11 'g' stands for ['gorgeous'](https://github.com/grpc/grpc/tree/v1.11.x)
- 1.12 'g' stands for ['glorious'](https://github.com/grpc/grpc/tree/v1.12.x)
- 1.13 'g' stands for ['gloriosa'](https://github.com/grpc/grpc/tree/v1.13.x)
- 1.14 'g' stands for ['gladiolus'](https://github.com/grpc/grpc/tree/v1.14.x)
- 1.15 'g' stands for ['glider'](https://github.com/grpc/grpc/tree/v1.15.x)
- 1.16 'g' stands for ['gao'](https://github.com/grpc/grpc/tree/v1.16.x)
- 1.17 'g' stands for ['gizmo'](https://github.com/grpc/grpc/tree/v1.17.x)
- 1.18 'g' stands for ['goose'](https://github.com/grpc/grpc/tree/v1.18.x)
- 1.19 'g' stands for ['gold'](https://github.com/grpc/grpc/tree/v1.19.x)
- 1.20 'g' stands for ['godric'](https://github.com/grpc/grpc/tree/v1.20.x)
- 1.21 'g' stands for ['gandalf'](https://github.com/grpc/grpc/tree/v1.21.x)
- 1.22 'g' stands for ['gale'](https://github.com/grpc/grpc/tree/v1.22.x)
- 1.23 'g' stands for ['gangnam'](https://github.com/grpc/grpc/tree/v1.23.x)
- 1.24 'g' stands for ['ganges'](https://github.com/grpc/grpc/tree/v1.24.x)
- 1.25 'g' stands for ['game'](https://github.com/grpc/grpc/tree/v1.25.x)
- 1.26 'g' stands for ['gon'](https://github.com/grpc/grpc/tree/v1.26.x)
- 1.27 'g' stands for ['guantao'](https://github.com/grpc/grpc/tree/v1.27.x)
- 1.28 'g' stands for ['galactic'](https://github.com/grpc/grpc/tree/v1.28.x)
- 1.29 'g' stands for ['gringotts'](https://github.com/grpc/grpc/tree/v1.29.x)
- 1.30 'g' stands for ['gradius'](https://github.com/grpc/grpc/tree/v1.30.x)
- 1.31 'g' stands for ['galore'](https://github.com/grpc/grpc/tree/v1.31.x)
- 1.32 'g' stands for ['giggle'](https://github.com/grpc/grpc/tree/v1.32.x)
- 1.33 'g' stands for ['geeky'](https://github.com/grpc/grpc/tree/v1.33.x)
- 1.34 'g' stands for ['gauntlet'](https://github.com/grpc/grpc/tree/v1.34.x)
- 1.35 'g' stands for ['gecko'](https://github.com/grpc/grpc/tree/v1.35.x)
- 1.36 'g' stands for ['gummybear'](https://github.com/grpc/grpc/tree/v1.36.x)
- 1.37 'g' stands for ['gilded'](https://github.com/grpc/grpc/tree/v1.37.x)
- 1.38 'g' stands for ['guadalupe_river_park_conservancy'](https://github.com/grpc/grpc/tree/v1.38.x)
- 1.39 'g' stands for ['goofy'](https://github.com/grpc/grpc/tree/v1.39.x)
- 1.40 'g' stands for ['guileless'](https://github.com/grpc/grpc/tree/v1.40.x)
- 1.41 'g' stands for ['goat'](https://github.com/grpc/grpc/tree/v1.41.x)
- 1.42 'g' stands for ['granola'](https://github.com/grpc/grpc/tree/v1.42.x)
- 1.43 'g' stands for ['green'](https://github.com/grpc/grpc/tree/v1.43.x)
- 1.44 'g' stands for ['great'](https://github.com/grpc/grpc/tree/v1.44.x)
- 1.45 'g' stands for ['gravity'](https://github.com/grpc/grpc/tree/v1.45.x)
- 1.46 'g' stands for ['golazo'](https://github.com/grpc/grpc/tree/v1.46.x)
- 1.47 'g' stands for ['gridman'](https://github.com/grpc/grpc/tree/v1.47.x)
- 1.48 'g' stands for ['garum'](https://github.com/grpc/grpc/tree/v1.48.x)
- 1.49 'g' stands for ['gamma'](https://github.com/grpc/grpc/tree/v1.49.x)
- 1.50 'g' stands for ['galley'](https://github.com/grpc/grpc/tree/v1.50.x)
- 1.51 'g' stands for ['galaxy'](https://github.com/grpc/grpc/tree/v1.51.x)
- 1.52 'g' stands for ['gribkoff'](https://github.com/grpc/grpc/tree/v1.52.x)
- 1.53 'g' stands for ['glockenspiel'](https://github.com/grpc/grpc/tree/v1.53.x)
- 1.54 'g' stands for ['gracious'](https://github.com/grpc/grpc/tree/v1.54.x)
- 1.55 'g' stands for ['grandslam'](https://github.com/grpc/grpc/tree/v1.55.x)
- 1.56 'g' stands for ['galvanized'](https://github.com/grpc/grpc/tree/v1.56.x)
- 1.57 'g' stands for ['grounded'](https://github.com/grpc/grpc/tree/v1.57.x)
- 1.58 'g' stands for ['goku'](https://github.com/grpc/grpc/tree/v1.58.x)
- 1.59 'g' stands for ['generative'](https://github.com/grpc/grpc/tree/v1.59.x)
- 1.60 'g' stands for ['gjallarhorn'](https://github.com/grpc/grpc/tree/v1.60.x)
- 1.61 'g' stands for ['grand'](https://github.com/grpc/grpc/tree/v1.61.x)
- 1.62 'g' stands for ['guardian'](https://github.com/grpc/grpc/tree/v1.62.x)
- 1.63 'g' stands for ['giggle'](https://github.com/grpc/grpc/tree/v1.63.x)
- 1.64 'g' stands for ['grateful'](https://github.com/grpc/grpc/tree/v1.64.x)
- 1.65 'g' stands for ['gnarly'](https://github.com/grpc/grpc/tree/v1.65.x)
- 1.66 'g' stands for ['gladiator'](https://github.com/grpc/grpc/tree/v1.66.x)
- 1.67 'g' stands for ['gesundheit'](https://github.com/grpc/grpc/tree/v1.67.x)
- 1.68 'g' stands for ['groovy'](https://github.com/grpc/grpc/tree/v1.68.x)
- 1.69 'g' stands for ['gridiron'](https://github.com/grpc/grpc/tree/v1.69.x)
- 1.70 'g' stands for ['genius'](https://github.com/grpc/grpc/tree/v1.70.x)
- 1.71 'g' stands for ['gears'](https://github.com/grpc/grpc/tree/v1.71.x)
- 1.72 'g' stands for ['gusto'](https://github.com/grpc/grpc/tree/v1.72.x)
- 1.73 'g' stands for ['gradient'](https://github.com/grpc/grpc/tree/v1.73.x)
- 1.74 'g' stands for ['gee'](https://github.com/grpc/grpc/tree/v1.74.x)
- 1.75 'g' stands for ['gemini'](https://github.com/grpc/grpc/tree/v1.75.x)

==> grpc-1.78.1.gh.tar.gz: grpc-1.78.1/doc/g_stands_for.md <==
'g' stands for something different every gRPC release:

- 1.0 'g' stands for ['gRPC'](https://github.com/grpc/grpc/tree/v1.0.x)
- 1.1 'g' stands for ['good'](https://github.com/grpc/grpc/tree/v1.1.x)
- 1.2 'g' stands for ['green'](https://github.com/grpc/grpc/tree/v1.2.x)
- 1.3 'g' stands for ['gentle'](https://github.com/grpc/grpc/tree/v1.3.x)
- 1.4 'g' stands for ['gregarious'](https://github.com/grpc/grpc/tree/v1.4.x)
- 1.6 'g' stands for ['garcia'](https://github.com/grpc/grpc/tree/v1.6.x)
- 1.7 'g' stands for ['gambit'](https://github.com/grpc/grpc/tree/v1.7.x)
- 1.8 'g' stands for ['generous'](https://github.com/grpc/grpc/tree/v1.8.x)
- 1.9 'g' stands for ['glossy'](https://github.com/grpc/grpc/tree/v1.9.x)
- 1.10 'g' stands for ['glamorous'](https://github.com/grpc/grpc/tree/v1.10.x)
- 1.11 'g' stands for ['gorgeous'](https://github.com/grpc/grpc/tree/v1.11.x)
- 1.12 'g' stands for ['glorious'](https://github.com/grpc/grpc/tree/v1.12.x)
- 1.13 'g' stands for ['gloriosa'](https://github.com/grpc/grpc/tree/v1.13.x)
- 1.14 'g' stands for ['gladiolus'](https://github.com/grpc/grpc/tree/v1.14.x)
- 1.15 'g' stands for ['glider'](https://github.com/grpc/grpc/tree/v1.15.x)
- 1.16 'g' stands for ['gao'](https://github.com/grpc/grpc/tree/v1.16.x)
- 1.17 'g' stands for ['gizmo'](https://github.com/grpc/grpc/tree/v1.17.x)
- 1.18 'g' stands for ['goose'](https://github.com/grpc/grpc/tree/v1.18.x)
- 1.19 'g' stands for ['gold'](https://github.com/grpc/grpc/tree/v1.19.x)
- 1.20 'g' stands for ['godric'](https://github.com/grpc/grpc/tree/v1.20.x)
- 1.21 'g' stands for ['gandalf'](https://github.com/grpc/grpc/tree/v1.21.x)
- 1.22 'g' stands for ['gale'](https://github.com/grpc/grpc/tree/v1.22.x)
- 1.23 'g' stands for ['gangnam'](https://github.com/grpc/grpc/tree/v1.23.x)
- 1.24 'g' stands for ['ganges'](https://github.com/grpc/grpc/tree/v1.24.x)
- 1.25 'g' stands for ['game'](https://github.com/grpc/grpc/tree/v1.25.x)
- 1.26 'g' stands for ['gon'](https://github.com/grpc/grpc/tree/v1.26.x)
- 1.27 'g' stands for ['guantao'](https://github.com/grpc/grpc/tree/v1.27.x)
- 1.28 'g' stands for ['galactic'](https://github.com/grpc/grpc/tree/v1.28.x)
- 1.29 'g' stands for ['gringotts'](https://github.com/grpc/grpc/tree/v1.29.x)
- 1.30 'g' stands for ['gradius'](https://github.com/grpc/grpc/tree/v1.30.x)
- 1.31 'g' stands for ['galore'](https://github.com/grpc/grpc/tree/v1.31.x)
- 1.32 'g' stands for ['giggle'](https://github.com/grpc/grpc/tree/v1.32.x)
- 1.33 'g' stands for ['geeky'](https://github.com/grpc/grpc/tree/v1.33.x)
- 1.34 'g' stands for ['gauntlet'](https://github.com/grpc/grpc/tree/v1.34.x)
- 1.35 'g' stands for ['gecko'](https://github.com/grpc/grpc/tree/v1.35.x)
- 1.36 'g' stands for ['gummybear'](https://github.com/grpc/grpc/tree/v1.36.x)
- 1.37 'g' stands for ['gilded'](https://github.com/grpc/grpc/tree/v1.37.x)
- 1.38 'g' stands for ['guadalupe_river_park_conservancy'](https://github.com/grpc/grpc/tree/v1.38.x)
- 1.39 'g' stands for ['goofy'](https://github.com/grpc/grpc/tree/v1.39.x)
- 1.40 'g' stands for ['guileless'](https://github.com/grpc/grpc/tree/v1.40.x)
- 1.41 'g' stands for ['goat'](https://github.com/grpc/grpc/tree/v1.41.x)
- 1.42 'g' stands for ['granola'](https://github.com/grpc/grpc/tree/v1.42.x)
- 1.43 'g' stands for ['green'](https://github.com/grpc/grpc/tree/v1.43.x)
- 1.44 'g' stands for ['great'](https://github.com/grpc/grpc/tree/v1.44.x)
- 1.45 'g' stands for ['gravity'](https://github.com/grpc/grpc/tree/v1.45.x)
- 1.46 'g' stands for ['golazo'](https://github.com/grpc/grpc/tree/v1.46.x)
- 1.47 'g' stands for ['gridman'](https://github.com/grpc/grpc/tree/v1.47.x)
- 1.48 'g' stands for ['garum'](https://github.com/grpc/grpc/tree/v1.48.x)
- 1.49 'g' stands for ['gamma'](https://github.com/grpc/grpc/tree/v1.49.x)
- 1.50 'g' stands for ['galley'](https://github.com/grpc/grpc/tree/v1.50.x)
- 1.51 'g' stands for ['galaxy'](https://github.com/grpc/grpc/tree/v1.51.x)
- 1.52 'g' stands for ['gribkoff'](https://github.com/grpc/grpc/tree/v1.52.x)
- 1.53 'g' stands for ['glockenspiel'](https://github.com/grpc/grpc/tree/v1.53.x)
- 1.54 'g' stands for ['gracious'](https://github.com/grpc/grpc/tree/v1.54.x)
- 1.55 'g' stands for ['grandslam'](https://github.com/grpc/grpc/tree/v1.55.x)
- 1.56 'g' stands for ['galvanized'](https://github.com/grpc/grpc/tree/v1.56.x)
- 1.57 'g' stands for ['grounded'](https://github.com/grpc/grpc/tree/v1.57.x)
- 1.58 'g' stands for ['goku'](https://github.com/grpc/grpc/tree/v1.58.x)
- 1.59 'g' stands for ['generative'](https://github.com/grpc/grpc/tree/v1.59.x)
- 1.60 'g' stands for ['gjallarhorn'](https://github.com/grpc/grpc/tree/v1.60.x)
- 1.61 'g' stands for ['grand'](https://github.com/grpc/grpc/tree/v1.61.x)
- 1.62 'g' stands for ['guardian'](https://github.com/grpc/grpc/tree/v1.62.x)
- 1.63 'g' stands for ['giggle'](https://github.com/grpc/grpc/tree/v1.63.x)
- 1.64 'g' stands for ['grateful'](https://github.com/grpc/grpc/tree/v1.64.x)
- 1.65 'g' stands for ['gnarly'](https://github.com/grpc/grpc/tree/v1.65.x)
- 1.66 'g' stands for ['gladiator'](https://github.com/grpc/grpc/tree/v1.66.x)
- 1.67 'g' stands for ['gesundheit'](https://github.com/grpc/grpc/tree/v1.67.x)
- 1.68 'g' stands for ['groovy'](https://github.com/grpc/grpc/tree/v1.68.x)
- 1.69 'g' stands for ['gridiron'](https://github.com/grpc/grpc/tree/v1.69.x)
- 1.70 'g' stands for ['genius'](https://github.com/grpc/grpc/tree/v1.70.x)
- 1.71 'g' stands for ['gears'](https://github.com/grpc/grpc/tree/v1.71.x)
- 1.72 'g' stands for ['gusto'](https://github.com/grpc/grpc/tree/v1.72.x)
- 1.73 'g' stands for ['gradient'](https://github.com/grpc/grpc/tree/v1.73.x)
- 1.74 'g' stands for ['gee'](https://github.com/grpc/grpc/tree/v1.74.x)
- 1.75 'g' stands for ['gemini'](https://github.com/grpc/grpc/tree/v1.75.x)
- 1.76 'g' stands for ['genuine'](https://github.com/grpc/grpc/tree/v1.76.x)
- 1.78 'g' stands for ['gutsy'](https://github.com/grpc/grpc/tree/v1.78.x)
